/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef CURVE_HH
#define CURVE_HH

#include "Math.hh"
#include <gtkmm/drawingarea.h>
#include <list>

namespace SharpConstruct
{
	class Curve
	{
	public:
		typedef Math::Point2D< float > Node;
		typedef std::vector< Node > List;

		Curve();

		const List& Nodes() const;
		void SetNode( const unsigned, const Node& );

		int AddNode( const Node& );
		int AddNode( float, float );

		void RemoveNode( const unsigned );

		void Update();
		const List& RenderCache() const;

		float Value( const float ) const;
	private:
		class NodeSort
		{
		public:
			bool operator()( const Node&,
					 const Node& ) const;
		};

		Node interpolate_( const int, const float ) const;
		float evaluate_( const int, const float ) const;

		List nodes_;
		List render_cache_;
	};

	class CurveEditor : public Gtk::DrawingArea
	{
	public:
		CurveEditor();

		const Curve& Data() const;
	protected:
		virtual bool on_expose_event( GdkEventExpose* );
		virtual bool on_button_press_event( GdkEventButton* );
		virtual bool on_motion_notify_event( GdkEventMotion* );
		virtual bool on_button_release_event( GdkEventButton* );
	private:
		static const unsigned RADIUS = 4;
		static const unsigned DIAMETER = RADIUS * 2;

		Gdk::Point project_( const Curve::Node& ) const;
		Curve::Node unproject_( const Gdk::Point& ) const;

		Curve curve_;
		int selected_node_;
	};
}

#endif
