/* Copyright 2006 Timon Christl
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef DATADIR_HH
#define DATADIR_HH

#include <glibmm/ustring.h>

#ifdef WIN32
#include "win32.h"
#else
#include "binreloc.h"
#endif

namespace SharpConstruct
{

	/**
	 * Return a Glib::ustring that contains the UTF-8 encoded absolute filename
	 * of the data "append_path", relative to the application's data directory.
	 *
	 * The application's data directory is platform-dependent.
	 */
	inline Glib::ustring DataDir( const Glib::ustring& append_path )
	{
#ifdef WIN32
		// On Win32 an overloaded version of br_datadir() from win32.cpp is used
		return br_datadir( append_path );
#else
		gchar* rawdir( gbr_find_data_dir( DATADIR ) );
		const Glib::ustring datadir( rawdir );
		free( rawdir );

		return datadir + append_path;
#endif
	}

}

#endif
