/* Copyright 2005 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "Create.hh"
#include "MeshHistory.hh"

using SharpConstruct::Create::Plane;
using SharpConstruct::Mesh;

Plane::Plane( const unsigned rows, const unsigned cols )
: rows_( rows ), columns_( cols )
{}

bool Plane::operator()( Mesh& ) const
{
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );

	const float half_x = columns_ / 2, half_y = rows_ / 2;

	const unsigned rowl( rows_ - 1 );
	const unsigned coll( columns_ - 1 );
	
	mesh.VertexLocations().reserve( rows_ * columns_ );
	mesh.Quads().reserve( rowl * coll );

	for( unsigned i = 0; i < rows_; ++i )
	{
		for( unsigned j = 0; j < columns_; ++j )
			mesh.VertexLocations().push_back( Point3D( ( j - half_x ) / coll, ( i - half_y ) / rowl, 0 ) );
	}

	for( unsigned i = 0; i < rowl; ++i )
	{
		for( unsigned j = 0; j < coll; ++j )
		{
			mesh.Quads().push_back( Quad( i * columns_ + j,
						      ( i + 1 ) * columns_ + j,
						      ( i + 1 ) * columns_ + j + 1,
						      i * columns_ + j + 1 ) );
		}
	}

	return true;
}
