/* Copyright 2005 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "GrabBrush.hh"
#include "Mesh.hh"
#include "Sculpt.hh"

using SharpConstruct::Brush::Grab;
using SharpConstruct::Brush::EditData;
using SharpConstruct::SculptStart;
using SharpConstruct::SculptContinue;

Grab::grab_data_ Grab::data_[ 8 ];
float Grab::delta_x_ = 0;
float Grab::delta_y_ = 0;

SharpConstruct::Brush::SupportedProperties Grab::Properties() const
{
	return SupportedProperties( false, false, false, false, false, false,
				    false, false, false );
}

bool Grab::SingleSelect() const
{
	return true;
}

unsigned Grab::Radius() const
{
	return BasicRadius();
}

void Grab::pre_start_sculpt_()
{
	for( unsigned i = 0; i < 8; ++i )
		data_[ i ].Active.clear();
	delta_x_ = delta_y_ = 0;
}
void Grab::pre_continue_sculpt_()
{}

void Grab::start_sculpt_( const EditData& e )
{
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );

	grab_data_& data( data_[ e.SymmetryIndex ] );

	data.Drag = Origin();

	mesh.FindActiveVertices( data.Active, e );
}

void Grab::continue_sculpt_( const EditData& e )
{
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );

	grab_data_& data( data_[ e.SymmetryIndex ] );

	data.Drag = Origin();
	data.Drag += e.Left * delta_x_;
	data.Drag += e.Up * delta_y_;
	
	for( unsigned i = 0; i < data.Active.size(); ++i )
		mesh.VertexLocations()[ data.Active[ i ].Index() ] += data.Drag * data.Active[ i ].Strength() * mesh.Mask( data.Active[ i ].Index() );
}

void Grab::SetDelta( float x, float y )
{
	delta_x_ = x;
	delta_y_ = y;
}
