/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "Mask.hh"
#include "MeshHistory.hh"

using SharpConstruct::Mask;

void Mask::Initialize( Glib::RefPtr< Gnome::Glade::Xml > glade )
{
	using sigc::mem_fun;

	glade_ = glade;

	glade_->connect_clicked( "MaskClear", mem_fun( *this, &Mask::clear_ ) );
	glade_->connect_clicked( "MaskInvert", mem_fun( *this, &Mask::invert_ ) );
}

void Mask::clear_()
{
	MeshHistory::Instance().AddMesh( false, true, false );
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );
	for( unsigned i = 0; i < mesh.VertexColors().size(); ++i )
		mesh.VertexColors()[ i ].SetMask( 0 );
	MeshHistory::Instance().SignalEntireSectionChanged().emit( false, true, false );
}

void Mask::invert_()
{
	MeshHistory::Instance().AddMesh( false, true, false );
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );
	for( unsigned i = 0; i < mesh.VertexColors().size(); ++i )
	{
		Color& col( mesh.VertexColors()[ i ] );
		col.SetMask( 1.0f - col.Mask() );
	}
	MeshHistory::Instance().SignalEntireSectionChanged().emit( false, true, false );
}
