/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "SaveDialog.hh"
#include "Utilities.hh"
#include <gtkmm/stock.h>

#include <iostream>

using SharpConstruct::SaveDialog;

SaveDialog::SaveDialog( const Glib::ustring& title, Gtk::Window& wnd, Gtk::FileFilter& def_filt )
: FileChooserDialog( title ), default_filter_( def_filt )
{
	set_transient_for( wnd );
	set_action( Gtk::FILE_CHOOSER_ACTION_SAVE );
	set_do_overwrite_confirmation( true );

	add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
	Gtk::Button* ok( add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_OK ) );

	ok->signal_pressed().connect( sigc::mem_fun( *this, &SaveDialog::check_extension_ ) );
}

void SaveDialog::check_extension_()
{
	if( !get_filter() )
		set_filter( default_filter_ );

	const std::string name( get_filter()->get_name() );
	const std::string ext( ExtractExtension( get_filename() ) );
	Glib::ustring append;

	if( name.find( "lwo" ) != std::string::npos && ext != "LWO" )
		append = ".lwo";
	else if( name.find( "obj" ) != std::string::npos && ext != "OBJ" )
		append = ".obj";
	else if( name.find( "wrl" ) != std::string::npos && ext != "WRL" )
		append = ".wrl";

	const std::string filename( get_filename() + append );
	set_filename( filename );
	set_current_name( g_path_get_basename( filename.c_str() ) );
}
