/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "Tools.hh"

using SharpConstruct::Tools;

Tools& Tools::Instance()
{
	static Tools tools;
	return tools;
}

SharpConstruct::Brush::BrushBase* Tools::Brush()
{
	return brush_;
}

void Tools::SetInitialBrushShape( Glib::RefPtr< Gdk::Pixbuf > shape,
				  const Gtk::TreePath t )
{
	displace_brush_.SetShape( shape, t );
	smooth_brush_.SetShape( shape, t );
	pinch_brush_.SetShape( shape, t );
	grab_brush_.SetShape( shape, t );
}

void Tools::SetDisplaceBrush()
{
	brush_ = &displace_brush_;
}

void Tools::SetGrabBrush()
{
	brush_ = &grab_brush_;
}

void Tools::SetPinchBrush()
{
	brush_ = &pinch_brush_;
}

void Tools::SetSmoothBrush()
{
	brush_ = &smooth_brush_;
}

bool Tools::InDeformationMode() const
{
	return deformation_ != 0;
}

SharpConstruct::DeformationBase* Tools::Deformation()
{
	return deformation_;
}

void Tools::DeactivateDeformation()
{
	delete deformation_;
	deformation_ = 0;
}

bool Tools::BrushCurveEnabled() const
{
	return brush_curve_enabled_;
}
void Tools::SetBrushCurveEnabled( const bool e )
{
	brush_curve_enabled_ = e;
}

SharpConstruct::CurveEditor& Tools::BrushCurve()
{
	return brush_curve_;
}

Tools::Tools()
: brush_( &displace_brush_ ),
  deformation_( 0 )
{}
